@@ -40,6 +40,10 @@ def gt_func(x: Any, y: Iterable) -> bool:
     return all(x > item for item in y)
 
 
+def gte_func(x: Any, y: Iterable) -> bool:
+    return all(x >= item for item in y)
+
+
 def gt_ix_func(cmp_list: list, x: Any, y: Iterable) -> bool:
     x_val = cmp_list.index(x)
     return all(x_val > cmp_list.index(item) for item in y)
@@ -49,6 +53,10 @@ def lt_func(x, y) -> bool:
     return all(x < item for item in y)
 
 
+def lte_func(x, y) -> bool:
+    return all(x <= item for item in y)
+
+
 def select_eq(
     value_objects: List[ValueObject],
     exact_match: bool,
@@ -67,6 +75,15 @@ def select_gt(
     return select(value_objects, exact_match, gt_func, labels, tree)
 
 
+def select_gte(
+    value_objects: List[ValueObject],
+    exact_match: bool,
+    labels: dict,
+    tree: Tree = None,
+) -> List[ValueObject]:
+    return select(value_objects, exact_match, gte_func, labels, tree)
+
+
 def select_gt_ix(
     value_objects: List[ValueObject],
     exact_match: bool,
@@ -90,3 +107,12 @@ def select_lt(
     tree: Tree = None,
 ) -> List[ValueObject]:
     return select(value_objects, exact_match, lt_func, labels, tree)
+
+
+def select_lte(
+    value_objects: List[ValueObject],
+    exact_match: bool,
+    labels: dict,
+    tree: Tree = None,
+) -> List[ValueObject]:
+    return select(value_objects, exact_match, lte_func, labels, tree)
